pub(crate) fn lc_error(err: Error) -> ErrorExpand description
Convert a query-service error to an AvailabilityError-carrying anyhow error so the HTTP
layer returns the status carried by the error (400/404) instead of 500.
pub(crate) fn lc_error(err: Error) -> ErrorConvert a query-service error to an AvailabilityError-carrying anyhow error so the HTTP
layer returns the status carried by the error (400/404) instead of 500.